<?php
namespace Aws\CloudSearchDomain\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with an Amazon CloudSearch Domain.
 */
class CloudSearchDomainException extends AwsException {}
